using DelimitedFiles
using Distributed
FNAME = "$(@__DIR__)/common.jl"
@everywhere include(FNAME)

Q = range(0.01,stop=5,length=100) 
L = (1/3,1/2,1)
Ic = (1,1,1)
C = (1,1,1)

NEV = 1
N = (15,15,15)
h = 0.000001

x = 4*Q.^2
s = map(x->(1 ./sqrt.(L.*C.*x),Ic./sqrt(2).*(L./(C.*x)).^(1/4)),x)

@sync begin
     @async global E0 = [sol[:EVALS] for sol in pmap(s->energies(s...,(0,0,0),N,NEV),s)]
     @async global Ex = [sol[:EVALS] for sol in pmap(s->energies(s...,(h,0,0),N,NEV),s)]
     @async global Ey = [sol[:EVALS] for sol in pmap(s->energies(s...,(0,h,0),N,NEV),s)]
     @async global Ez = [sol[:EVALS] for sol in pmap(s->energies(s...,(0,0,h),N,NEV),s)]
end

DEx = (Ex - E0)/h 
DEy = (Ey - E0)/h
DEz = (Ez - E0)/h

ΔEx = hcat(DEx...)'
ΔEy = hcat(DEy...)'
ΔEz = hcat(DEz...)'

ΔEz_ = ΔEz .* sqrt(2).*(C[3].* 4 * Q.^2 ./L[3]).^(1/4)./Ic[3]
ΔEy_ = ΔEy .* sqrt(2).*(C[2].* 4 * Q.^2 ./L[2]).^(1/4)./Ic[3]
ΔEx_ = ΔEx .* sqrt(2).*(C[1].* 4 * Q.^2 ./L[1]).^(1/4)./Ic[3]

writedlm("$(@__DIR__)/fig3c.dat", hcat(Q, ΔEx_, ΔEy_, ΔEz_))
