using DelimitedFiles
using Distributed
FNAME = "$(@__DIR__)/common.jl"
@everywhere include(FNAME)

### In units where 2e=ħ=1
L = (1/3,1/2,1)
Ic = (1,1,1)
C = (1,1,1).*100
ϕr = range(0,stop=1,length=10)

### Energy and phase units as in the main text
EB = maximum(L.*Ic.^2)/2
ϕ0 = Ic[3]*L[3]

# Number of eignevalues NEV and basis cutoff N
NEV = 4
N = (10,10,10)

### Conversion to parametrization used in numerics
ω = 1 ./sqrt.(L.*C)
Is = Ic./sqrt(2)./(C./L).^(1/4)
αn = (L./C).^(1/4)./sqrt(2)

@sync begin
    #@async global resultsx = pmap(x->energies(ω,Is,(x,0,0),N,NEV),ϕr./αn[1])
    @async global resultsy = pmap(x->energies(ω,Is,(0,x,0),N,NEV),ϕr./αn[2])
    @async global resultsz = pmap(x->energies(ω,Is,(0,0,x),N,NEV),ϕr./αn[3])
end

ϕ = collect(ϕr)

Ez = hcat([i[:EVALS] for i in resultsz]...)'
writedlm("$(@__DIR__)/fig3a.dat", hcat(ϕ, Ez))

Ey = hcat([i[:EVALS] for i in resultsy]...)'
writedlm("$(@__DIR__)/fig3b.dat", hcat(ϕ, Ey))

