using DelimitedFiles
ENV["MPLCONFIGDIR"] = dirname(@__DIR__)
using PyPlot; const plt = PyPlot
@info "Config file $(matplotlib.matplotlib_fname())"

rc("svg",fonttype="none")
top,bottom,left,right = 0.97,0.12,0.22,0.99

linspace(x,y,z) = range(x,y,length=z)

FNAME = "$(@__DIR__)/nanostructure-energies.jld" 

# Variables used in the dataset
gx,gy,gz = 3,2,1
Cx,Cy,Cz = (1,1,1).*100
αx,αy,αz = (1,1,1)

#NLEVELS = 300
FMT = "-"
COLOR = "firebrick"

fig = figure()
fig.set_size_inches(3.487/3,3.487/1.618)
subplots_adjust(top=top,bottom=bottom,left=left,right=right)

tick_params(axis="both", which="major", labelsize=6)
tick_params(axis="both", which="minor", labelsize=6)

xticks([0,0.5,1])

xlim(0,1)
ylim(-1.5,+0.5)

data = readdlm("$(@__DIR__)/fig3b.dat", '\t', Float64, '\n')
ϕ = data[:,1]
E = data[:,2:end]

for i in 1:size(E,2)
    plot(ϕ,E[:,i],FMT,color=COLOR,lw=0.25)
end

### Quasicalssical plot in easy direction
### Quasicalssical plot
AXIS = "y"
COLOR = "firebrick"
FMT = "-"
gx,gy,gz = 3,2,1
Cx,Cy,Cz = (1,1,1).*100
αx,αy,αz = (1,1,1)

### Quasicalssical plot
Ix,Iy,Iz = 1,1,1

### a=+1
r = collect(0:0.01:3)
φy1 = Iy/gy .+ r
Ey1 = Iy^2/2/gy .+ Iy*r
φy2 = collect(0:0.01:Iy/gy)
Ey2 = gy*φy2.^2/2

plt.plot(φy1,Ey1,"-r")
plt.plot(φy2,Ey2,"-r")

### a=-1
r = collect(Iz^2/gz/Iy:0.01:7)
φy1 = r .- Iy/gy
Ey1 = Iy^2/2/gy .- Iy*r
φy2 = collect(0:0.01:Iz/gz/Iy - Iy/gy)
Ey2 = - Iz^2/2/gz .- 1/2*Iy^2/(Iz^2/gz - Iy^2/gy)*φy2.^2
 
ϕ = [φy2;φy1]
Ey = [Ey2;Ey1]

plot(ϕ,Ey,"-r",lw=1)
plt.plot(maximum(φy2),minimum(Ey2),".r")

ylabel(L"E/2E_B")
xlabel(L"\phi^r_2/\phi_0")

savefig("$(@__DIR__)/fig3b.svg")
