using DelimitedFiles
using Distributed
FNAME = "$(@__DIR__)/common.jl"
@everywhere include(FNAME)

v = (1,1)
m = (1,1/2) 
Q = range(0.01,stop=20,length=100)

# The N specified is small enough so that user computer can do the calculation in an hour. This however is not large enough for a small Q where numerical artifact comes in. Thus in paper N=400 was used with h=1e-6.
N = 150 #400 
#h = 1e-6 
h = 1e-4
σoff = -0.5
NEV = 2
L = 20

αs = 1 ./sqrt.(Q) 

@sync begin
    @async global E0 = pmap(x->energies(x,v,m,(0,0),L,N,NEV,σoff),αs)
    @async global Ex = pmap(x->energies(x,v,m,(h,0),L,N,NEV,σoff),αs)
    @async global Ey = pmap(x->energies(x,v,m,(0,h),L,N,NEV,σoff),αs)
end

DEx = (Ex .- E0)/h
DEy = (Ey .- E0)/h

writedlm("$(@__DIR__)/fig4c.dat", hcat(Q, [i[1] for i in DEx], [i[2] for i in DEx], [i[1] for i in DEy], [i[2] for i in DEy]))

