using DelimitedFiles
using Distributed
FNAME = "$(@__DIR__)/common.jl"
@everywhere include(FNAME)

v = (1,1)
m = (1,1/2)
α = 1/sqrt(20)
p0 = range(0,stop=0.2,length=20)

NEV = 5
N = 150#50
ΔN = 10 
L = 20
σ = -0.5 - 2*α^2 # some empirical formula

@sync begin
    @async global E1x = pmap(x->energies(α,v,m,(x,0),L,N-ΔN,NEV,σ),p0)
    @async global E2x = pmap(x->energies(α,v,m,(x,0),L,N+ΔN,NEV,σ),p0)
    @async global E1y = pmap(x->energies(α,v,m,(0,x),L,N-ΔN,NEV,σ),p0)
    @async global E2y = pmap(x->energies(α,v,m,(0,x),L,N+ΔN,NEV,σ),p0)
end

### Now performing Richardson extrapolation
function EXTRAPOLATOR(x,y)
    x1,x2 = x[1],x[2]
    y1,y2 = y[1],y[2]

    A = (x1^3*y2 - x2^3*y1)/(x1^3-x2^3)
    B = (y1-y2)/(x1^3-x2^3)

    return A
end

Ex = EXTRAPOLATOR((1/(N-ΔN),1/(N+ΔN)),(E1x,E2x))
Ey = EXTRAPOLATOR((1/(N-ΔN),1/(N+ΔN)),(E1y,E2y))

p = collect(p0)
writedlm("$(@__DIR__)/fig4a.dat", hcat(p, hcat([i for i in Ex]...)'))
writedlm("$(@__DIR__)/fig4b.dat", hcat(p, hcat([i for i in Ey]...)'))
